#
# spec file for package signon-plugin-oauth2
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           signon-plugin-oauth2
Version:        0.25
Release:        1.12
Summary:        Oauth2 plugin for the Single Sign On Framework
License:        LGPL-2.0-only
Group:          System/GUI/Other
URL:            https://gitlab.com/accounts-sso/signon-plugin-oauth2
Source:         %{url}/-/archive/VERSION_%{version}/signon-plugin-oauth2-VERSION_%{version}.tar.bz2
Patch0:         0001_Multilib.patch
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(libsignon-qt5)
BuildRequires:  pkgconfig(signon-plugins)
Requires:       signon-ui
Conflicts:      libproxy1-config-kde4

%description
This package contains the Oauth2 plugin for the Single Sign On Framework.

%package devel
Summary:        Development files for signon-plugin-oauth2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contains the development files for the Oauth2 plugin for the Single
Sign On Framework.

%prep
%setup -q -n signon-plugin-oauth2-VERSION_%{version}

%patch0 -p1 -b .multilib
sed -i 's|@LIB@|%{_lib}|g' src/signon-oauth2plugin.pc src/src.pro

%build
mkdir build
pushd build
%qmake5 \
  PREFIX=%{_prefix} \
  LIBDIR=%{_libdir} \
  QMAKE_CXXFLAGS+="-Wno-error=deprecated-declarations" \
  ..
%make_jobs
popd

%install
pushd build
%qmake5_install
# Remove examples and tests
rm -rf %{buildroot}/%{_bindir} %{buildroot}/%{_datadir}
popd

%files
%license COPYING
%doc README.md
%dir %{_libdir}/signon/
%{_libdir}/signon/liboauth2plugin.so

%files devel
%dir %{_includedir}/signon-plugins/
%{_includedir}/signon-plugins/*.h
%{_libdir}/pkgconfig/signon-oauth2plugin.pc

%changelog
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.25
  * OAuth2: try using specialized hostname first, use "Host" as
    fallback only
  * OAuth1: add UserAgent parameter
  * OAuth2: pass token query in request body
  * OAuth2: always try normal authentication if refresh token fails
  * OAuth2: let the client read all extra info from the response
  * Plugin: implement also new AuthPluginInterface2
* Tue Apr  9 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Don't treat use of deprecated declarations as error to fix build
  against Qt 5.13
* Sat Sep  8 2018 fabian@ritter-vogt.de
- Don't install examples and tests
* Fri Nov  3 2017 buschmann23@opensuse.org
- update to version 0.24
  * OAuth2: allow token URL to be on a different host
  * OAuth2: accept replies carrying text/html content type
- update to version 0.23
  * OAuth: propagate network and SSL errors from SignOnUI
  * OAuth2: add an option to disable "state" parameter
  * Base: disconnect from reply on SSL errors
- update to version 0.22
  * OAuth2: add the list of granted permissions to the reply
  * OAuth2: use "state" parameter to check for CSRF
  * Build with QT 5 only
  * OAuth2: Use QUrlQuery to parse callback fragment
  * OAuth2: handle errors occurring when refreshing a token
- update to version 0.21
  * OAuth2: implement a fallback mechanism when parsing replies
  * OAuth 1.0a and 2.0: allow forcing a new token
  * Delay instantiation of QNetworkAccessManager
- updated patches
  * 0001_Multilib.patch
* Sat Jun  4 2016 wbauer@tmo.at
- Conflict with libproxy1-config-kde4, that's the actual name of
  the package, and having it installed makes the plugin crash
  (boo#953175)
* Sat Feb 22 2014 tittiatcoke@gmail.com
- Initial package
